@@ -95,6 +95,8 @@ identifiers = [
         'http://www.ncbi.nlm.nih.gov/pubmed/12082125'),
     ('http://purl.oclc.org/foo/bar', ['purl', 'url'], '',
         'http://purl.oclc.org/foo/bar'),
+    ('https://purl.fdlp.gov/GPO/gpo154197', ['purl', 'url'], '',
+        'https://purl.fdlp.gov/GPO/gpo154197'),
     ('http://www.heatflow.und.edu/index2.html', ['url'], '',
         'http://www.heatflow.und.edu/index2.html'),
     ('urn:nbn:de:101:1-201102033592', ['urn'], '',
@@ -228,6 +230,8 @@ identifiers = [
          'swh:1:dir:d198bc9d7a6bcf6db04f476d29314f157507d505'
          ';origin=https://github.com/user/repo')),
     ('03yrm5c26', ['ror'], '03yrm5c26', 'http://ror.org/03yrm5c26'),
+    ('http://ror.org/03yrm5c26', ['ror', 'url'], '03yrm5c26',
+     'http://ror.org/03yrm5c26'),
     (('swh:1:cnt:78e48f800c950530e36d3712d9e2e89673f23562'
       ';origin=https://github.com/python/cpython'
       ';visit=swh:1:snp:cd510e99a42139ed36f15a5774301c113c3e494b'
